@@ -121,12 +121,28 @@ namespace Aws
                 /**
                  * Default constructor
                  */
-                IncomingPublishEvent() : m_payload() { AWS_ZERO_STRUCT(m_payload); }
+                IncomingPublishEvent() : m_topic(), m_payload()
+                {
+                    AWS_ZERO_STRUCT(m_topic);
+                    AWS_ZERO_STRUCT(m_payload);
+                }
+
+                /**
+                 * Sets the message response topic associated with this event.  The event does not own this topic.
+                 *
+                 * @param topic the message response topic associated with this event
+                 * @return reference to this
+                 */
+                IncomingPublishEvent &WithTopic(Aws::Crt::ByteCursor topic)
+                {
+                    m_topic = topic;
+                    return *this;
+                }
 
                 /**
                  * Sets the message payload associated with this event.  The event does not own this payload.
                  *
-                 * @param payload he message payload associated with this event
+                 * @param payload the message payload associated with this event
                  * @return reference to this
                  */
                 IncomingPublishEvent &WithPayload(Aws::Crt::ByteCursor payload)
@@ -135,6 +151,13 @@ namespace Aws
                     return *this;
                 }
 
+                /**
+                 * Gets the message response topic associated with this event.
+                 *
+                 * @return the message response topic associated with this event
+                 */
+                Aws::Crt::ByteCursor GetTopic() const { return m_topic; }
+
                 /**
                  * Gets the message payload associated with this event.
                  *
@@ -143,6 +166,7 @@ namespace Aws
                 Aws::Crt::ByteCursor GetPayload() const { return m_payload; }
 
               private:
+                Aws::Crt::ByteCursor m_topic;
                 Aws::Crt::ByteCursor m_payload;
             };
 
